summaryrefslogtreecommitdiffstats
path: root/src/platformsupport
diff options
context:
space:
mode:
authorDmitry Shachnev <mitya57@gmail.com>2015-11-04 00:06:19 +0300
committerDmitry Shachnev <mitya57@gmail.com>2015-11-13 05:32:26 +0000
commite8763912068f4501240cea0b5ae53b25c3d0aa04 (patch)
tree3af530fa64b73c779349250add2f2cc60a88db9d /src/platformsupport
parentf05c75a1b978336210175e80060d3083cff915c8 (diff)
Port the Gtk platform theme to Gtk+ 3
The major changes compared to the Gtk+ 2 version are: * Everything is ported to modern Gtk/Gdk API. * GtkFontChooserDialog is used instead of deprecated GtkFontSelectionDialog. * Hiding buttons on dialogs (like OK/Cancel) is no longer supported, as it is impossible to do that with dialogs using GtkHeaderBars. * Some workarounds were added to the QGtk3Theme constructor to correctly work with Gtk+ 3. [ChangeLog][Platform Specific Changes] The Gtk+ platform theme has been ported to Gtk+ 3. Change-Id: Iacb01279b6432e0901e3bb1353d5792543cc76e4 Done-with: J-P Nurmi <jpnurmi@theqtcompany.com> Reviewed-by: Oswald Buddenhagen <oswald.buddenhagen@theqtcompany.com> Reviewed-by: Lisandro Damián Nicanor Pérez Meyer <perezmeyer@gmail.com> Reviewed-by: J-P Nurmi <jpnurmi@theqtcompany.com>
Diffstat (limited to 'src/platformsupport')
-rw-r--r--src/platformsupport/themes/genericunix/qgenericunixthemes.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/platformsupport/themes/genericunix/qgenericunixthemes.cpp b/src/platformsupport/themes/genericunix/qgenericunixthemes.cpp
index 26d815d7ff..e12cda25ba 100644
--- a/src/platformsupport/themes/genericunix/qgenericunixthemes.cpp
+++ b/src/platformsupport/themes/genericunix/qgenericunixthemes.cpp
@@ -713,9 +713,9 @@ QStringList QGenericUnixTheme::themeNames()
result.push_back(QLatin1String(QKdeTheme::name));
#endif
} else if (gtkBasedEnvironments.contains(desktopName)) {
- // prefer the GTK2 theme implementation with native dialogs etc.
- result.push_back(QStringLiteral("gtk2"));
- // fallback to the generic Gnome theme if loading the GTK2 theme fails
+ // prefer the GTK3 theme implementation with native dialogs etc.
+ result.push_back(QStringLiteral("gtk3"));
+ // fallback to the generic Gnome theme if loading the GTK3 theme fails
result.push_back(QLatin1String(QGnomeTheme::name));
}
}